@@ -17,6 +17,7 @@ from github_poster.loader.strava_loader import StravaLoader
 from github_poster.loader.twitter_loader import TwitterLoader
 from github_poster.loader.wakatime_loader import WakaTimeLoader
 from github_poster.loader.youtube_loader import YouTubeLoader
+from github_poster.loader.json_loader import JsonLoader
 
 LOADER_DICT = {
     "duolingo": DuolingoLoader,
@@ -38,6 +39,7 @@ LOADER_DICT = {
     "multiple": MutipleLoader,
     "nike": NRCLoader,
     "garmin": GarminLoader,
+    "json": JsonLoader,
 }
 
 __all__ = (
@@ -61,4 +63,5 @@ __all__ = (
     "NRCLoader",
     "LOADER_DICT",
     "GarminLoader",
+    "JsonLoader",
 )
