@@ -1,5 +1,6 @@
 import json
 from collections import defaultdict
+import os
 
 import pendulum
 
@@ -21,7 +22,7 @@ class YouTubeLoader(BaseLoader):
             "--youtube_history_file_file",
             dest="youtube_history_file",
             type=str,
-            default="IN_FOLDER/watch-history.json",
+            default=os.path.join("IN_FOLDER", "watch-history.json"),
             help="youtube history file path",
         )
 
